VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package tfrmtbuilder

Package {tfrmtbuilder}


Title: 'shiny' App Companion to the 'tfrmt' Package
Version: 0.1.1
Description: Provides an interactive interface to the 'tfrmt' package. Users can import, modify, and export tables and templates with little to no code.
License: Apache License (≥ 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: tfrmt (≥ 0.1.0), shiny, shinyjs, dplyr, stringr, purrr, DT, gt, rlang, sortable, bslib (≥ 0.6.0), shinyWidgets, rio, shinycssloaders, webshot2, shinyAce, shinyFeedback, fontawesome
Suggests: here, pkgload, rprojroot, shinytest2, testthat (≥ 3.0.0)
Config/testthat/edition: 3
URL: https://gsk-biostatistics.github.io/tfrmtbuilder/, https://github.com/GSK-Biostatistics/tfrmtbuilder
BugReports: https://github.com/GSK-Biostatistics/tfrmtbuilder/issues
NeedsCompilation: no
Packaged: 2026-02-11 18:29:08 UTC; bkrouse
Author: Becca Krouse [aut, cre], Christina Fillmore ORCID iD [aut], Karima Ahmad ORCID iD [aut], Ellis Hughes ORCID iD [aut], GlaxoSmithKline Research & Development Limited [cph, fnd]
Maintainer: Becca Krouse <becca.z.krouse@gsk.com>
Repository: CRAN
Date/Publication: 2026-02-11 18:50:02 UTC

Run tfrmt Builder Shiny App

Description

Run tfrmt Builder Shiny App

Usage

tfrmtbuilder(tfrmt = NULL, data = NULL, mockmode = TRUE, run = TRUE)

Arguments

tfrmt

tfrmt object to be loaded into app from R session. Defaults to NULL

data

data frame to be loaded into app from R session. Defaults to NULL

mockmode

Whether to initialize the app in mock mode. Defaults to TRUE

run

Boolean for whether the created object should be run directly. Set to FALSE for deployment

Value

Shiny app for creating and modifying tfrmt objects

Examples

if (interactive()){
  tfrmtbuilder()
}

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.