| Title: | 'shiny' App Companion to the 'tfrmt' Package |
|---|---|
| Description: | Provides an interactive interface to the 'tfrmt' package. Users can import, modify, and export tables and templates with little to no code. |
| Authors: | Becca Krouse [aut, cre], Christina Fillmore [aut] (ORCID: <https://orcid.org/0000-0003-0595-2302>), Karima Ahmad [aut] (ORCID: <https://orcid.org/0000-0002-8784-1712>), Ellis Hughes [aut] (ORCID: <https://orcid.org/0000-0003-0637-4436>), GlaxoSmithKline Research & Development Limited [cph, fnd] |
| Maintainer: | Becca Krouse <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-19 09:26:38 UTC |
| Source: | https://github.com/gsk-biostatistics/tfrmtbuilder |
Run tfrmt Builder Shiny App
tfrmtbuilder(tfrmt = NULL, data = NULL, mockmode = TRUE, run = TRUE)tfrmtbuilder(tfrmt = NULL, data = NULL, mockmode = TRUE, run = TRUE)
tfrmt |
tfrmt object to be loaded into app from R session. Defaults to |
data |
data frame to be loaded into app from R session. Defaults to |
mockmode |
Whether to initialize the app in mock mode. Defaults to |
run |
Boolean for whether the created object should be run directly. Set to |
Shiny app for creating and modifying tfrmt objects
if (interactive()){ tfrmtbuilder() }if (interactive()){ tfrmtbuilder() }